@@ -141,15 +141,16 @@ class Storage(driver.Base):
             raise exceptions.FileNotFoundError("File not found %s" % path)
         
     def stream_write(self, path, fp):
-         logger.info("stream_write path:%s" % path)
+         logger.info("stream_write path:%s " % path)
          path1 = self._init_path(path)
-         part_size = 5 * 1024 * 1024
-         
-         if self.buffer_size < part_size:
-             part_size = self.buffer_size
+
          try:
              object_instance = self._jss.bucket(self._bucket).object(path1)
-             object_instance.multi_upload_fp_with_size(None, fp, self.buffer_size, part_size)
+             l = fp.read(self.buffer_size)
+             logger.info("stream_write,begin to write the content to jss ")
+             while len(l) > 0:
+                 object_instance.upload_flow(None, l, True)
+                 l = fp.read(self.buffer_size)
          except Exception as e :
             logger.error("stream_write error:%s" % e)
             raise e
